summaryrefslogtreecommitdiff
path: root/desktop/gui.h
diff options
context:
space:
mode:
Diffstat (limited to 'desktop/gui.h')
-rw-r--r--desktop/gui.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/desktop/gui.h b/desktop/gui.h
index 0b2c6c0c0..dc2841fb8 100644
--- a/desktop/gui.h
+++ b/desktop/gui.h
@@ -139,15 +139,15 @@ void gui_cert_verify(const char *url, const struct ssl_cert_info *certs,
/**
* Callback to translate resource to full url.
*
* Transforms a resource: filename into a full URL. The returned URL
* is used as the target for a redirect. The caller takes ownership of
* the returned nsurl including unrefing it when finished with it.
*
* \param filename The filename of the resource to locate.
* \return A string containing the full URL of the target object or
* NULL if no suitable resource can be found.
*/
-char* gui_get_resource_url(const char *filename);
+nsurl* gui_get_resource_url(const char *path);
/** css callback to obtain named system colours from a frontend. */
css_error gui_system_colour(void *pw, lwc_string *name, css_color *color);
@@ -139,15 +139,15 @@ void gui_cert_verify(const char *url, const struct ssl_cert_info *certs,
* Callback to translate resource to full url.
*
- * Transforms a resource: filename into a full URL. The returned URL
+ * Transforms a resource: path into a full URL. The returned URL
* is used as the target for a redirect. The caller takes ownership of
* the returned nsurl including unrefing it when finished with it.
@@ -139,15 +139,15 @@ void gui_cert_verify(const char *url, const struct ssl_cert_info *certs,
* the returned nsurl including unrefing it when finished with it.
*
- * \param filename The filename of the resource to locate.
+ * \param path The path of the resource to locate.
* \return A string containing the full URL of the target object or
* NULL if no suitable resource can be found.